Multi-line text input
=====================

The Multi-line text input is similar to the text input but designed for larger inputs, similar to the textarea field of HTML.

Usage
-----

.. code-block:: Python

    import toga
    
    textbox = toga.MultilineTextInput(id='view1')

Supported Platforms
-------------------

.. include:: ../supported_platforms/MultilineTextInput.rst

Reference
---------

.. autoclass:: toga.interface.widgets.multilinetextinput.MultilineTextInput
   :members:
   :undoc-members:
   :inherited-members: